@@ -18,11 +18,11 @@ from endi_celery.models import (
 logger = logging.getLogger(__name__)
 
 
-SALARYSHEET_MAIL_MESSAGE = u"""Bonjour,
+SALARYSHEET_MAIL_MESSAGE = """Bonjour,
 Vous trouverez ci-joint votre bulletin de salaire.
 """
 
-SALARYSHEET_MAIL_SUBJECT = u"Votre bulletin de salaire"
+SALARYSHEET_MAIL_SUBJECT = "Votre bulletin de salaire"
 
 
 def send_salary_sheet(
@@ -54,16 +54,16 @@ def send_salary_sheet(
     filedatas = filebuf.read()
 
     if not force and check_if_mail_sent(filedatas, company_id):
-        logger.warn(u"Mail already sent : mail already sent")
-        raise MailAlreadySent(u"Mail already sent")
+        logger.warn("Mail already sent : mail already sent")
+        raise MailAlreadySent("Mail already sent")
 
     filebuf.seek(0)
 
     if email is None:
         logger.warn(
-            u"Undelivered email : no mail provided for company {0}".format(company_id)
+            "Undelivered email : no mail provided for company {0}".format(company_id)
         )
-        raise UndeliveredMail(u"no mail provided for company {0}".format(company_id))
+        raise UndeliveredMail("no mail provided for company {0}".format(company_id))
     else:
         logger.info("Sending the file %s" % filepath)
         logger.info("Sending it to %s" % email)
