@@ -1081,7 +1081,7 @@ def collect_operations(
         )
 
 
-def run_compiler(compiler_type: str, upload_id: int):
+def run_compiler(compiler_type: str, upload_id: int, mail: bool = True):
     """
     Collect accounting operations to be used by the compiler factory
     """
@@ -1122,13 +1122,14 @@ def run_compiler(compiler_type: str, upload_id: int):
         return False
     else:
         logger.info("{0} measure grids were handled".format(len(grids)))
-        send_success(
-            request,
-            mail_addresses,
-            compiler.label,
-            compiler.get_message(grids),
-        )
-        logger.info("A success email has been sent to {0}".format(mail_addresses))
+        if mail:
+            send_success(
+                request,
+                mail_addresses,
+                compiler.label,
+                compiler.get_message(grids),
+            )
+            logger.info("A success email has been sent to {0}".format(mail_addresses))
 
     transaction.commit()
     logger.info("The transaction has been commited")
@@ -1138,7 +1139,9 @@ def run_compiler(compiler_type: str, upload_id: int):
 LOCK_NAME = "measure_compute"
 
 
-def compile_measures(upload_id: int, grid_type: Optional[str] = None):
+def compile_measures(
+    upload_id: int, grid_type: Optional[str] = None, mail: bool = True
+):
     """Compile accounting measures related to upload id
 
     :param grid_type: One of the available grid_type (income_statement,
@@ -1158,7 +1161,7 @@ def compile_measures(upload_id: int, grid_type: Optional[str] = None):
             grid_types = list(GRID_COMPILERS.keys())
 
         for grid_type in grid_types:
-            run_compiler(grid_type, upload_id)
+            run_compiler(grid_type, upload_id, mail)
     except Exception:
         logger.exception("Erreur inconnue")
 
@@ -1209,5 +1212,5 @@ since yesterday"
         )
     else:
         for upload in uploads:
-            compile_measures(upload.id)
+            compile_measures(upload.id, mail=False)
         logger.info("===> End of scheduled compile measure task for synchronized datas")
